@@ -1,6 +1,6 @@
 package Net::Amazon::S3::Operation::Object::Acl::Set::Request;
 # ABSTRACT: An internal class to set an object's access control
-$Net::Amazon::S3::Operation::Object::Acl::Set::Request::VERSION = '0.98';
+$Net::Amazon::S3::Operation::Object::Acl::Set::Request::VERSION = '0.99';
 use Moose 0.85;
 use MooseX::StrictConstructor 0.16;
 
@@ -46,7 +46,7 @@ Net::Amazon::S3::Operation::Object::Acl::Set::Request - An internal class to set
 
 =head1 VERSION
 
-version 0.98
+version 0.99
 
 =head1 SYNOPSIS
 
@@ -60,7 +60,7 @@ version 0.98
 
 =head1 DESCRIPTION
 
-Implements operation L<< PutObjectAcl|https://docs.aws.amazon.com/AmazonS3/latest/API/API_PutObjectAcl.html>.
+Implements operation L<< PutObjectAcl|https://docs.aws.amazon.com/AmazonS3/latest/API/API_PutObjectAcl.html >>.
 
 This module sets an object's access control.
 
