@@ -1,6 +1,6 @@
 package Net::Amazon::S3::Operation::Objects::List::Request;
 # ABSTRACT: An internal class to list a bucket (List Objects Version 1)
-$Net::Amazon::S3::Operation::Objects::List::Request::VERSION = '0.98';
+$Net::Amazon::S3::Operation::Objects::List::Request::VERSION = '0.99';
 use Moose 0.85;
 use MooseX::StrictConstructor 0.16;
 use URI::Escape qw(uri_escape_utf8);
@@ -28,7 +28,7 @@ Net::Amazon::S3::Operation::Objects::List::Request - An internal class to list a
 
 =head1 VERSION
 
-version 0.98
+version 0.99
 
 =head1 SYNOPSIS
 
@@ -44,7 +44,7 @@ version 0.98
 
 This module lists a bucket.
 
-Implements operation L<< ListObjects|https://docs.aws.amazon.com/AmazonS3/latest/API/API_ListObjects.html >.
+Implements operation L<< ListObjects|https://docs.aws.amazon.com/AmazonS3/latest/API/API_ListObjects.html >>.
 
 =for test_synopsis no strict 'vars'
 
