@@ -1,6 +1,6 @@
 package Net::Amazon::S3::Operation::Objects::List::Response;
 # ABSTRACT: An internal class to list a bucket (List Objects Version 1)
-$Net::Amazon::S3::Operation::Objects::List::Response::VERSION = '0.98';
+$Net::Amazon::S3::Operation::Objects::List::Response::VERSION = '0.99';
 use Moose;
 
 extends 'Net::Amazon::S3::Response';
@@ -99,11 +99,11 @@ Net::Amazon::S3::Operation::Objects::List::Response - An internal class to list
 
 =head1 VERSION
 
-version 0.98
+version 0.99
 
 =head1 DESCRIPTION
 
-Implements operation L<< ListObjects|https://docs.aws.amazon.com/AmazonS3/latest/API/API_ListObjects.html >.
+Implements operation L<< ListObjects|https://docs.aws.amazon.com/AmazonS3/latest/API/API_ListObjects.html >>.
 
 =head1 AUTHOR
 
